@@ -156,13 +156,19 @@ class Watcher:
         try:
             self._run_callback(new)
             self._number_of_callback_args = 1
+            return
         except WrongNumberOfArgumentsError:
-            try:
-                self._run_callback(new, old)
-                self._number_of_callback_args = 2
-            except WrongNumberOfArgumentsError:
-                self._run_callback()
-                self._number_of_callback_args = 0
+            pass
+
+        try:
+            self._run_callback()
+            self._number_of_callback_args = 0
+            return
+        except WrongNumberOfArgumentsError:
+            pass
+
+        self._run_callback(new, old)
+        self._number_of_callback_args = 2
 
     def _run_callback(self, *args):
         """
